@@ -45,7 +45,7 @@ class Connector(APIResource):
         return cls.s3_path
 
     @classmethod
-    def get_client_path(cls, user_token: str = None):
+    def get_client_path(cls, path: bool = False, user_token: str = None):
         file_list = []
         cls.get_credentials(user_token)
         os.environ['AWS_ACCESS_KEY_ID'] = cls.credentials['access_key']
@@ -55,8 +55,13 @@ class Connector(APIResource):
         fs = s3fs.S3FileSystem()
         try:
             file_list = fs.ls(cls.get_s3_path(user_token=user_token), refresh=True)
-            # remove first item - path item
-            file_list.pop(0)
+            if not path:
+                if len(file_list) > 0:
+                    # remove first item - path location
+                    pre_path = file_list.pop(0)
+                    # remove path from list
+                    file_list = {x.replace(str(pre_path), '') for x in file_list}
+
         except PermissionError as ex:
             print(' '.join(['folder is empty:', str(ex)]))
         return file_list
