@@ -630,12 +630,12 @@ class MyWhatify:
         return my_toolkit.Connector.get_s3_path(user_token=user_token)
 
     @classmethod
-    def get_data_file_s3(cls, file_name: str):
-        logging.info("Deprecated func: get_data_file_s3, please use read_to_pandas_df function")
-        return cls.read_to_pandas_df(file_name=file_name)
+    def read_to_pandas_df(cls, file_name: str):
+        logging.info("Deprecated func: read_to_pandas_df, please use get_data_file_s3 function")
+        return cls.get_data_file_s3(file_name=file_name)
 
     @classmethod
-    def read_to_pandas_df(cls, file_name: str, user_token: str = None, **kwargs):
+    def get_data_file_s3(cls, file_name: str, user_token: str = None, **kwargs):
         """
         read s3 to panda
         Args:
